#include <QtWidgets>

#include "mainwindow.h"

MainWindow::MainWindow()
{
    model=new XmlModel(this);
    treeView=new QTreeView(this);
    treeView->setModel(model);
    treeView->setContextMenuPolicy(Qt::ContextMenuPolicy());
    setCentralWidget(treeView);

    treeView->setContextMenuPolicy(Qt::CustomContextMenu);
    connect(treeView, SIGNAL(customContextMenuRequested(QPoint)), SLOT(contextMenu(QPoint)));

    createActions();
    createMenus();

    setWindowTitle(tr("Menu"));
    setMinimumSize(160, 160);
    resize(480, 320);
}

MainWindow::~MainWindow(){
    delete model;
    delete treeView;

    delete fileMenu;
    delete openAct;
    delete closeAct;
    delete exitAct;
    delete makeActiveAct;
}

void MainWindow::contextMenu(QPoint index)
{
    if(model->getObjectByIndex(model->parent(treeView->indexAt(index)))==model->getRoot()){
        QMenu menu(this);
        model->setCurrentIndex(treeView->indexAt(index));
        menu.addAction(makeActiveAct);
        menu.addAction(openNewAct);
        menu.exec(QCursor::pos());
    }
}

void MainWindow::open()
{
    QStringList FilesName = QFileDialog::getOpenFileNames(this,tr("Open XML-file"),"","XML-file(*.xml)");
    model->addFiles(&FilesName);
    treeView->reset(); //Reset the internal state of the view.
}

void MainWindow::close()
{
    delete model;
    model=new XmlModel(this);
    treeView->setModel(model);
    treeView->reset();
}

void MainWindow::openNew()
{
    // make new window
    auto obj = model->getObjectByIndex(model->getCurrentIndex());
    QStringList strlist;
    QVariant str;
    str = obj->property("fullname");
    strlist = str.toStringList();

    NewWindow = new AnotherWindow(strlist);
    NewWindow->show();

    // close file
    QObject* Rootnew=new QObject(this);
    bool isActive=false;
    for(QObject* obj:model->getRoot()->children()){
        if(obj==model->getObjectByIndex(model->getCurrentIndex()))
                obj->setParent(Rootnew);
        else if (obj->property("bold")==true) isActive=true;
    }
    if(!isActive) model->getRoot()->children().at(0)->setProperty("bold",true);
    treeView->reset();
}

void MainWindow::createActions()
{
    openAct = new QAction(tr("&Open..."), this);
    openAct->setShortcuts(QKeySequence::Open);
    openAct->setStatusTip(tr("Open an existing file"));
    connect(openAct, &QAction::triggered, this, &MainWindow::open);

    closeAct = new QAction(tr("&Close all"), this);
    closeAct->setShortcuts(QKeySequence::Close);
    closeAct->setStatusTip(tr("Close all documents"));
    connect(closeAct, &QAction::triggered, this, &MainWindow::close);

    exitAct = new QAction(tr("E&xit"), this);
    exitAct->setShortcuts(QKeySequence::Quit);
    exitAct->setStatusTip(tr("Exit the application"));
    connect(exitAct, &QAction::triggered, this, &QWidget::close);

    makeActiveAct = new QAction(tr("Make Active"), this);
    makeActiveAct->setStatusTip(tr("Make active the current selection's contents"));
    connect(makeActiveAct, &QAction::triggered, model, &XmlModel::makeActiveObj);

    openNewAct = new QAction(tr("Open in a new window"), this);
    openNewAct->setStatusTip(tr("Open in a new window the current selection's contents"));
    connect(openNewAct, &QAction::triggered, this, &MainWindow::openNew);
}

void MainWindow::createMenus()
{
    fileMenu = menuBar()->addMenu(tr("&File"));
    fileMenu->addAction(openAct);
    fileMenu->addAction(closeAct);
    fileMenu->addSeparator();
    fileMenu->addAction(exitAct);
}

